@@ -7,34 +7,20 @@
 # SPDX-FileCopyrightText: 2024 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
-from __future__ import print_function
-
+import builtins
 import subprocess
-import sys
+import urllib.parse
+import urllib.response
 from io import BytesIO, StringIO, TextIOWrapper
 from os.path import abspath, dirname, join
+from typing import IO, Any, Dict, List, Sequence, Union
 
 import pytest
-import six
-from six.moves import urllib_parse, urllib_response
 
 import univention.updater.tools as U  # noqa: E402
 from univention.config_registry import ConfigRegistry
 
 
-try:
-    from typing import IO, Any, Dict, List, Sequence, Union  # noqa: F401
-except ImportError:
-    pass
-
-if sys.version_info >= (3,):
-    import builtins
-else:
-    import __builtin__ as builtins
-    FileNotFoundError = IOError
-    collect_ignore = ["modules/univention/updater/scripts", "umc/python/updater/__init__.py"]
-
-
 # from tests/mockups.py
 MAJOR, MINOR, PATCH = RELEASE = (3, 0, 1)
 ERRAT = 3
@@ -78,7 +64,7 @@ def ucr(monkeypatch, tmpdir):
 
 @pytest.fixture()
 def http(mocker):
-    """Mock HTTP requests via py2:urllib2 / py3:urllib.requests"""
+    """Mock HTTP requests via py3:urllib.requests"""
     ressources = {}
 
     def extra(uris={}, netloc=""):
@@ -87,7 +73,7 @@ def http(mocker):
 
     def fopen(req, *args, **kwargs):
         url = req.get_full_url()
-        p = urllib_parse.urlparse(url)
+        p = urllib.parse.urlparse(url)
         try:
             try:
                 res = ressources[p.netloc][p.path]
@@ -97,15 +83,15 @@ def http(mocker):
             if isinstance(res, Exception):
                 raise res
             elif isinstance(res, bytes):
-                return urllib_response.addinfourl(BytesIO(res), {"content-length": len(res)}, url, 200)
+                return urllib.response.addinfourl(BytesIO(res), {"content-length": len(res)}, url, 200)
             else:
                 return res
         except LookupError:
-            raise U.urllib_error.HTTPError(url, 404, "Not Found", {}, None)
+            raise U.urllib.error.HTTPError(url, 404, "Not Found", {}, None)
 
-    director = mocker.patch("univention.updater.tools.urllib2.OpenerDirector", autospec=True)
+    director = mocker.patch("univention.updater.tools.urllib.request.OpenerDirector", autospec=True)
     director.open.side_effect = fopen
-    opener = mocker.patch("univention.updater.tools.urllib2.build_opener")
+    opener = mocker.patch("univention.updater.tools.urllib.request.build_opener")
     opener.return_value = director
     U.UCSHttpServer.reinit()
 
@@ -115,7 +101,7 @@ def http(mocker):
 class MockPopen(object):
     """Mockup for :py:class:`subprocess.Popen`."""
 
-    mock_commands = []  # type: List[Sequence[str]]
+    mock_commands: List[Sequence[str]] = []
     mock_stdout = b''
     mock_stderr = b''
 
@@ -127,12 +113,12 @@ class MockPopen(object):
         if shell:
             MockPopen.mock_commands.append(cmd)
         else:
-            if isinstance(cmd, six.string_types):
+            if isinstance(cmd, str):
                 cmd = (cmd,)
             try:
                 with open(cmd[0]) as fd_script:
                     content = fd_script.read(1024)
-            except (EnvironmentError, UnicodeDecodeError) as ex:
+            except (OSError, UnicodeDecodeError) as ex:
                 content = ex
             MockPopen.mock_commands.append(tuple(cmd) + (content,))
 
@@ -179,14 +165,12 @@ def mockpopen(monkeypatch):
 class MockFileManager(object):
     """Mockup for :py:func:`open()`"""
 
-    def __init__(self, tmpdir):
-        # type: (Any) -> None
-        self.files = {}  # type: Dict[str, Union[StringIO, BytesIO, Exception]]
+    def __init__(self, tmpdir: Any) -> None:
+        self.files: Dict[str, Union[StringIO, BytesIO, Exception]] = {}
         self._open = builtins.open
         self._tmpdir = tmpdir
 
-    def open(self, name, mode='r', buffering=-1, **options):
-        # type: (str, str, int, **Any) -> IO
+    def open(self, name: str, mode: str = 'r', buffering: int = -1, **options: Any) -> IO:
         name = abspath(name)
         buf = self.files.get(name)
 
@@ -217,22 +201,19 @@ class MockFileManager(object):
 
         return TextIOWrapper(buf, "utf-8") if isinstance(buf, BytesIO) and not binary else buf
 
-    def _new(self, name, data=b""):
-        # type: (str, Union[bytes, str]) -> Union[StringIO, BytesIO]
-        buf = BytesIO(data) if isinstance(data, bytes) else StringIO(data)  # type: Union[StringIO, BytesIO]
+    def _new(self, name: str, data: Union[bytes, str] = b"") -> Union[StringIO, BytesIO]:
+        buf: Union[StringIO, BytesIO] = BytesIO(data) if isinstance(data, bytes) else StringIO(data)
         buf.name = name
         buf.close = lambda: None
         buf.fileno = lambda: -1
         return buf
 
-    def write(self, name, text):
-        # type: (str, bytes) -> None
+    def write(self, name: str, text: bytes) -> None:
         name = abspath(name)
         buf = self._new(name, text)
         self.files[name] = buf
 
-    def read(self, name):
-        # type: (str) -> bytes
+    def read(self, name: str) -> bytes:
         name = abspath(name)
         if name not in self.files:
             raise FileNotFoundError(2, "No such file or directory: '%s'" % name)
@@ -242,8 +223,7 @@ class MockFileManager(object):
         val = buf.getvalue()
         return val if isinstance(val, bytes) else val.encode("utf-8")
 
-    def __setitem__(self, name, ex):
-        # type: (str, Exception) -> None
+    def __setitem__(self, name: str, ex: Exception) -> None:
         name = abspath(name)
         self.files[name] = ex
 
