@@ -30,10 +30,8 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 """Univention Updater exceptions."""
-try:
-    from typing import Set  # noqa: F401
-except ImportError:
-    pass
+
+from typing import Set
 
 
 class UpdaterException(Exception):
@@ -56,13 +54,11 @@ class RequiredComponentError(UpdaterException):
     :type components: set(str)
     """
 
-    def __init__(self, version, components):
-        # type: (str, Set[str]) -> None
+    def __init__(self, version: str, components: Set[str]) -> None:
         self.version = version
         self.components = components
 
-    def __str__(self):
-        # type: () -> str
+    def __str__(self) -> str:
         """
         >>> raise RequiredComponentError('4.0-0', set(('a',)))  # doctest: +IGNORE_EXCEPTION_DETAIL
         Traceback (most recent call last):
@@ -95,8 +91,7 @@ class PreconditionError(UpdaterException):
     univention.updater.errors.PreconditionError: ('preup', 'main', None, 'preup.sh')
     """
 
-    def __init__(self, phase, order, component, script):
-        # type: (str, str, str, str) -> None
+    def __init__(self, phase: str, order: str, component: str, script: str) -> None:
         Exception.__init__(self, phase, order, component, script)
 
 
@@ -110,8 +105,7 @@ class DownloadError(UpdaterException):
     univention.updater.errors.DownloadError: Error downloading file:///preup.sh: 404
     """
 
-    def __str__(self):
-        # type: () -> str
+    def __str__(self) -> str:
         return "Error downloading %s: %d" % self.args
 
 
@@ -125,8 +119,7 @@ class ConfigurationError(UpdaterException):
     univention.updater.errors.ConfigurationError: Configuration error: not found
     """
 
-    def __str__(self):
-        # type: () -> str
+    def __str__(self) -> str:
         return "Configuration error: %s" % self.args[1]
 
 
@@ -140,8 +133,7 @@ class VerificationError(ConfigurationError):
     univention.updater.errors.VerificationError: Verification error: not signed
     """
 
-    def __str__(self):
-        # type: () -> str
+    def __str__(self) -> str:
         return "Verification error: %s" % self.args[1]
 
 
@@ -158,13 +150,11 @@ class CannotResolveComponentServerError(ConfigurationError):
     univention.updater.errors.CannotResolveComponentServerError: Cannot resolve component server for disabled component 'comp' (mirror_list=False).
     """
 
-    def __init__(self, component, for_mirror_list):
-        # type: (str, bool) -> None
+    def __init__(self, component: str, for_mirror_list: bool) -> None:
         self.component = component
         self.for_mirror_list = for_mirror_list
 
-    def __str__(self):
-        # type: () -> str
+    def __str__(self) -> str:
         return "Cannot resolve component server for disabled component '%s' (mirror_list=%s)." % (self.component, self.for_mirror_list)
 
 
@@ -178,8 +168,7 @@ class ProxyError(ConfigurationError):
     univention.updater.errors.ProxyError: Proxy configuration error: blocked file:///preup.sh
     """
 
-    def __str__(self):
-        # type: () -> str
+    def __str__(self) -> str:
         return "Proxy configuration error: %s %s" % (self.args[1], self.args[0])
 
 
@@ -193,6 +182,5 @@ class UnmetDependencyError(UpdaterException):
     univention.updater.errors.UnmetDependencyError: You have unmet dependencies stderr
     """
 
-    def __str__(self):
-        # type: () -> str
+    def __str__(self) -> str:
         return "You have unmet dependencies %s" % self.args[0]
