@@ -33,7 +33,6 @@
 
 """Creates a local repository."""
 
-from __future__ import print_function
 
 import errno
 import subprocess
@@ -146,7 +145,7 @@ def main() -> None:
         # create symbolic link univention-repository
         try:
             symlink('.', join(options.base, 'mirror', 'univention-repository'))
-        except EnvironmentError as ex:
+        except OSError as ex:
             if ex.errno != errno.EEXIST:
                 raise
 
