@@ -32,7 +32,7 @@
 
 """Install UCS release and errata updates."""
 
-from __future__ import print_function
+from __future__ import annotations
 
 import logging
 import os
@@ -42,7 +42,7 @@ import sys
 import time
 import traceback
 from argparse import ArgumentParser, FileType, Namespace
-from typing import Iterable, List, NoReturn, Optional, Tuple
+from typing import Iterable, List, NoReturn, Tuple
 
 from univention.admindiary.client import write_event
 from univention.admindiary.events import UPDATE_FINISHED_FAILURE, UPDATE_FINISHED_SUCCESS, UPDATE_STARTED
@@ -102,11 +102,11 @@ def update_status(**kwargs: str) -> None:
         with open(fn, 'w+') as fd:
             for key, val in updater_status.items():
                 fd.write('%s=%s\n' % (key, val))
-    except EnvironmentError:
+    except OSError:
         dprint(silent, 'Warning: cannot update %s' % fn)
     try:
         os.rename(fn, FN_STATUS)
-    except EnvironmentError:
+    except OSError:
         dprint(silent, 'Warning: cannot update %s' % FN_STATUS)
 
 
@@ -133,7 +133,7 @@ def _package_list(new_packages: Iterable[Tuple[str, ...]]) -> str:
     return ",".join(p[0] for p in new_packages)
 
 
-def performUpdate(options: Namespace, checkForUpdates: bool = False, silent: bool = False) -> Optional[bool]:
+def performUpdate(options: Namespace, checkForUpdates: bool = False, silent: bool = False) -> bool | None:
     for func in (do_package_updates, do_app_updates, do_release_update):
         if func(options, checkForUpdates, silent):
             if checkForUpdates:
@@ -236,7 +236,7 @@ def do_package_updates(options: Namespace, checkForUpdates: bool, silent: bool)
     return True
 
 
-def do_app_updates(options: Namespace, checkForUpdates: bool, silent: bool) -> Optional[bool]:
+def do_app_updates(options: Namespace, checkForUpdates: bool, silent: bool) -> bool | None:
     dprint(silent, 'Checking for app updates: ', newline=False)
     if not options.app_updates:
         dprint(silent, 'skipped')
@@ -321,7 +321,7 @@ def do_app_updates(options: Namespace, checkForUpdates: bool, silent: bool) -> O
     return not success  # pending updates
 
 
-def parse_args(argv: Optional[List[str]] = None) -> Namespace:
+def parse_args(argv: List[str] | None = None) -> Namespace:
     parser = ArgumentParser(description=__doc__)
     parser.add_argument(
         "--updateto",
@@ -398,7 +398,7 @@ def main() -> None:
         handler.setFormatter(formatter)
         logger.addHandler(handler)
         logger.setLevel(logging.ERROR)
-    except EnvironmentError:
+    except OSError:
         print('Cannot open %s for writing' % LOGFN)
         sys.exit(1)
 
